module LCDCounterH (w_Enable, w_CTWrite, w_OutAddr, PixelClk, Reset);

input PixelClk, Reset;
output 	w_Enable, w_CTWrite, w_OutAddr; 

reg [9:0] COUNTH, COUNTADDR; //Counter Variable for Horizontal, CSDPRAM Address Counter
reg [19:0] COUNTV; //Counter Variable for Vertical
reg reg_EnableH, reg_EnableV; //Separate hBlank/vBlank signals -> anded to get enable
wire w_Enable, w_CTWrite; // Overall enable signal, Clear to Write signal 
wire [9:0] w_OutAddr; // Address Output -> CSDPRAM 

// A modulus 860 up counter generating horz enable and blanking
   always @(negedge PixelClk) 
   begin
	COUNTH = COUNTH + 1; 			//Increment Count Value
	
	if ((COUNTH >= 10'd860) || Reset) 	//If Reset asserted or reached end of  period
		begin				//horz blanking reset counter and set Enable
		reg_EnableH=1'b1;
		COUNTH = 0;
		end
	else if (COUNTH == 10'd800)		//If reached end of active line, take
		reg_EnableH=1'b0;		// enable line low.
	end

   always@(negedge PixelClk)
   begin
	COUNTV = COUNTV + 1; 			//Increment Count Value
	
	if ((COUNTV >= 20'd528900) || Reset) 	//If Reset asserted or reached end of period
		begin				//vert blanking reset counter and set Enable
		reg_EnableV=1'b1;
		COUNTV = 0;
		end
	else if (COUNTV >= 20'd516000)		//If reached end of active frame, take
		reg_EnableV=1'b0;		// enable line low.
	end

// A modulus 860 up counter one count ahead of COUNTH. Used for address generation
// for the CSDPRAM to output line data to the LCD.
   always @(negedge PixelClk) 
   begin
	COUNTADDR = COUNTADDR + 1; 		//Increment Address Count Value
	
	if (Reset)
	begin
		COUNTADDR=10'd1;		//If reset signal asserted, set address counter to
	end					// 1 (ie Enable Counter + 1).

	else if (COUNTADDR >= 10'd860) 		//If reset not asserted, reset address counter 
		begin				//when it reaches end of h. blank period.
			COUNTADDR = 0;
		end
	
	end

	
assign w_OutAddr=COUNTADDR; 			//Link Address Counter to address output
assign w_Enable=(reg_EnableH && reg_EnableV); 	//Generate final enable signal
assign w_CTWrite=~reg_EnableH; 			// Generate "Write new data" signal for DSP - active
						// for V.Blank period.
endmodule

